{
# Snowfall Lib provides a customized `lib` instance with access to your flake's library
# as well as the libraries available from your flake's inputs.
lib,
# An instance of `pkgs` with your overlays and packages applied is also available.
pkgs,
# You also have access to your flake's inputs.
inputs,

# Additional metadata is provided by Snowfall Lib.
system, # The system architecture for this host (eg. `x86_64-linux`).
target, # The Snowfall Lib target for this system (eg. `x86_64-iso`).
format, # A normalized name for the system target (eg. `iso`).
virtual
, # A boolean to determine whether this system is a virtual target using nixos-generators.
systems, # An attribute map of your defined hosts.

# All other arguments come from the module system.
config, ... }:

with lib;

let cfg = config.modules.shell.zsh;
in {
  options.modules.shell.zsh = { enable = mkOption { default = false; }; };

  config = mkIf cfg.enable {

    home.file = { ".config/starship.toml".source = ./starship.toml; };

    home.packages = with pkgs; [ starship ];

    programs.starship = {
      enable = true;
      enableZshIntegration = true;
    };

    programs.zsh = {
      enable = true;

      initExtra = builtins.readFile ./key-bindings.zsh
        + builtins.readFile ./functions.zsh
        + builtins.readFile ./last-working-dir.zsh
        + builtins.readFile ./dir-navigation.zsh;

      zplug = {
        enable = true;
        plugins = [
          # list of plugins: https://github.com/unixorn/awesome-zsh-plugins
          { name = "agkozak/zsh-z"; }
          {
            name = "zsh-users/zsh-completions";
          }

          # make it behave like fish
          { name = "zsh-users/zsh-autosuggestions"; }
          { name = "zsh-users/zsh-history-substring-search"; }
          {
            name = "zsh-users/zsh-syntax-highlighting";
          } # must be last sourced plugin
        ];
      };
    };
  };
}
